@@ -1,7 +1,7 @@
 from typing import Optional
 
 
-def recurring_fibonacci_number(number: int) -> Optional[int]:
+def recurring_fibonacci_number(number: int) -> int:
     """
     Calculates the fibonacci number needed.
 
@@ -9,9 +9,11 @@ def recurring_fibonacci_number(number: int) -> Optional[int]:
     :return: (Optional[int]) the calculated fibonacci number
     """
     if number < 0:
-        return None
+            raise ValueError(
+            "Fibonacci has to be equal or above zero"
+            )
     elif number <= 1:
         return number
     else:
         return recurring_fibonacci_number(number - 1) + \
-               recurring_fibonacci_number(number - 2)
\ No newline at end of file
+                recurring_fibonacci_number(number - 2)
\ No newline at end of file
