@@ -1,4 +1,4 @@
-from typing import List
+from typing import List, Optional
 
 from .fib_number import recurring_fibonacci_number
 
