@@ -12,9 +12,12 @@ class RecurringFibNumberTest(TestCase):
         )
 
     def test_negative(self):
-        self.assertEqual(
-            None, recurring_fibonacci_number(number=-1)
-        )
+        with self.assertRaises(ValueError) as raised_error:
+            recurring_fibonacci_number(number=-1)
+            self.assertEqual(
+                "Fibonacci has to be equal or above zero",
+                str(raised_error.exception)
+            )
 
     def test_one(self):
         self.assertEqual(
